@@ -3,11 +3,11 @@ package Function::Parameters;
 use v5.14.0;
 use warnings;
 
-use Carp qw(confess);
+use Carp qw(croak confess);
 
 use XSLoader;
 BEGIN {
-    our $VERSION = '1.0603_03';
+    our $VERSION = '1.0702_01';
     our $XS_VERSION = $VERSION;
     $VERSION = eval $VERSION;
     XSLoader::load;
@@ -99,40 +99,32 @@ our @type_reifiers = \&_reify_type_default;
 sub import {
     my $class = shift;
 
-    if (!@_) {
-        @_ = {
+    my $imports =
+        @_ == 0 ? {
             fun    => 'function',
             method => 'method',
-        };
-    }
-    if (@_ == 1) {
-        if ($_[0] eq ':strict') {
-            @_ = {
+        } :
+        @_ == 1 ?
+            $_[0] eq ':strict' ? {
                 fun    => 'function_strict',
                 method => 'method_strict',
-            };
-        } elsif ($_[0] eq ':lax') {
-            @_ = {
+            } :
+            $_[0] eq ':lax' ? {
                 fun    => 'function_lax',
                 method => 'method_lax',
-            };
-        }
-
-        if (ref($_[0]) eq 'HASH') {
-            @_ = map [$_, $_[0]{$_}], keys %{$_[0]};
-        }
-    }
+            } :
+            ref($_[0]) eq 'HASH' ?
+                $_[0] :
+            croak qq{"$_[0]" is not exported by the $class module}
+        :
+        croak "Too many arguments in import list for the $class module"
+    ;
 
     my %spec;
 
-    my $bare = 0;
-    for my $proto (@_) {
-        my $item = ref $proto
-            ? $proto
-            : [$proto, $bare_arms[$bare++] || confess(qq{Don't know what to do with "$proto"})]
-        ;
-        my ($name, $proto_type) = @$item;
+    for my $name (sort keys %$imports) {
         _assert_valid_identifier $name;
+        my $proto_type = $imports->{$name};
 
         $proto_type = {defaults => $proto_type} unless ref $proto_type;
 
@@ -433,7 +425,7 @@ question.
 =head3 Attributes
 
 Attributes are relatively unusual in Perl code, but if you want them, they work
-exactly the same as with L<C<sub>|perlsub/Subroutine-Attributes>.
+exactly the same as with L<C<sub>|perlsub/Subroutine Attributes>.
 
 =head3 Prototype
 
@@ -445,7 +437,7 @@ runtime (e.g. because it's called as a method or through a reference).
 
 With L<C<sub>|perlsub>, a prototype comes directly after the function name (if
 any). C<Function::Parameters> reserves this spot for the
-L<parameter list|/"Parameter list">. To specify a prototype, put it as the
+L<parameter list|/Parameter list>. To specify a prototype, put it as the
 first attribute (e.g. C<fun foo :(&$$)>). This is syntactically unambiguous
 because normal L<attributes|/Attributes> need a name after the colon.
 
@@ -473,8 +465,8 @@ A parameter list can include the following 6 parts, all of which are optional:
 
 This is a scalar variable followed by a colon (C<:>) and no comma. If an
 invocant is present in the parameter list, the first element of
-L<C<@_>|perlvar/@ARG> is automatically L<C<shift>ed|perlfunc/shift> off and
-placed in this variable. This is intended for methods:
+L<C<@_>|perlvar/@ARG> is automatically L<C<shift>ed|perlfunc/shift ARRAY> off
+and placed in this variable. This is intended for methods:
 
   method new($class: %init) {
     return bless { %init }, $class;
@@ -617,9 +609,10 @@ containing all unrecognized keys:
 
 =back
 
-Apart from the L<C<shift>|perlfunc/shift> performed by the L<invocant|/"1.
-Invocant">, all of the above leave L<C<@_>|perlvar/@ARG> unchanged; and if you
-don't specify a parameter list at all, L<C<@_>|perlvar/@ARG> is all you get.
+Apart from the L<C<shift>|perlfunc/shift ARRAY> performed by the
+L<invocant|/1. Invocant>, all of the above leave L<C<@_>|perlvar/@ARG>
+unchanged; and if you don't specify a parameter list at all,
+L<C<@_>|perlvar/@ARG> is all you get.
 
 =head3 Keyword
 
@@ -698,15 +691,16 @@ default for methods.
 =item C<shift>
 
 Valid values: strings that look like scalar variables. This lets you specify a
-default L<invocant|/"1. Invocant">, i.e. a function defined with this keyword
+default L<invocant|/1. Invocant>, i.e. a function defined with this keyword
 that doesn't have an explicit invocant in its parameter list will automatically
-L<C<shift>|perlfunc/shift> its first argument into the variable specified here.
+L<C<shift>|perlfunc/shift ARRAY> its first argument into the variable specified
+here.
 
 =item C<invocant>
 
 Valid values: booleans. If you set this to a true value, the keyword will
-accept L<invocants|/"1. Invocant"> in parameter lists; otherwise specifying
-an invocant in a function defined with this keyword is a syntax error.
+accept L<invocants|/1. Invocant> in parameter lists; otherwise specifying an
+invocant in a function defined with this keyword is a syntax error.
 
 =item C<attributes>
 
@@ -812,14 +806,15 @@ You can ask a function at runtime what parameters it has. This functionality is
 available through the function C<Function::Parameters::info> (which is not
 exported, so you have to call it by its full name). It takes a reference to a
 function, and returns either C<undef> (if it knows nothing about the function)
-or a L<Function::Parameters::Info> object describing the parameter list.
+or a L<C<Function::Parameters::Info>|Function::Parameters::Info> object
+describing the parameter list.
 
-Note: This feature is implemented using L<Moo>, so you'll need to have L<Moo>
-installed if you want to call C<Function::Parameters::info> (alternatively, if
-L<Moose> is already loaded by the time C<Function::Parameters::info> is first
-called, it will use that instead).
+Note: This feature is implemented using L<C<Moo>|Moo>, so you'll need to have
+L<C<Moo>|Moo> installed if you want to call C<Function::Parameters::info>
+(alternatively, if L<C<Moose>|Moose> is already loaded by the time
+C<Function::Parameters::info> is first called, it will use that instead).
 
-See L<Function::Parameters::Info> for examples.
+See L<C<Function::Parameters::Info>|Function::Parameters::Info> for examples.
 
 =head2 Wrapping C<Function::Parameters>
 
@@ -845,8 +840,8 @@ consisting of identifiers (C<Foo>), unions (C<... | ...>), and parametric types
 
 If you do this, the type reification function corresponding to the keyword will
 be called to turn the type (a string) into a constraint object. The default
-type reifier simply loads L<Moose> and forwards to
-L<C<Moose::Util::TypeConstraints::find_or_parse_type_constraint>|Moose::Util::TypeConstraints/find_or_parse_type_constraint>,
+type reifier simply loads L<C<Moose>|Moose> and forwards to
+L<C<Moose::Util::TypeConstraints::find_or_parse_type_constraint>|Moose::Util::TypeConstraints/find_or_parse_type_constraint($type_name)>,
 which creates L<Moose types|Moose::Manual::Types>.
 
 If you are in "lax" mode, nothing further happens and the types are ignored. If
@@ -855,7 +850,7 @@ any values passed in conform to the type (via
 L<< C<< $constraint->check($value) >>|Moose::Meta::TypeConstraint/$constraint->check($value) >>).
 
 In addition, these type constraints are inspectable through the
-L<Function::Parameters::Info> object returned by
+L<C<Function::Parameters::Info>|Function::Parameters::Info> object returned by
 L<C<Function::Parameters::info>|/Introspection>.
 
 =head2 Experimental experimental feature: Type expressions
@@ -880,7 +875,7 @@ The module is actually written in L<C|perlxs> and uses
 L<C<PL_keyword_plugin>|perlapi/PL_keyword_plugin> to generate opcodes directly.
 However, you can run L<C<perl -MO=Deparse ...>|B::Deparse> on your code to see
 what happens under the hood. In the simplest case (no argument checks, possibly
-an L<invocant|/"1. Invocant">, required positional/slurpy parameters only), the
+an L<invocant|/1. Invocant>, required positional/slurpy parameters only), the
 generated code corresponds to:
 
   fun foo($x, $y, @z) { ... }
@@ -912,7 +907,7 @@ You can also look for information at:
 
 =item MetaCPAN
 
-L<https://metacpan.org/module/Function%3A%3AParameters>
+L<https://metacpan.org/pod/Function%3A%3AParameters>
 
 =item RT, CPAN's request tracker
 
